@@ -1,7 +1,6 @@
 (*---------------------------------------------------------------------------
-   Copyright (c) 2008 Daniel C. Bünzli. All rights reserved.
+   Copyright (c) 2008 The uuidm programmers. All rights reserved.
    Distributed under the ISC license, see terms at the end of the file.
-   %%NAME%% %%VERSION%%
   ---------------------------------------------------------------------------*)
 
 let strf = Printf.sprintf
@@ -82,15 +81,14 @@ let cmd =
     `P "This program is distributed with the Uuidm OCaml library.
         See %%PKG_HOMEPAGE%% for contact information."; ]
   in
-  Term.(const gen $ version $ ns $ name_ $ upper $ binary),
-  Term.info "uuidtrip" ~version:"%%VERSION%%" ~doc ~man
+  Cmd.v (Cmd.info "uuidtrip" ~version:"%%VERSION%%" ~doc ~man)
+    Term.(const gen $ version $ ns $ name_ $ upper $ binary)
 
-let () = match Term.eval cmd with
-| `Error _ -> exit 1
-| _ -> exit 0
+
+let () = exit (Cmd.eval cmd)
 
 (*---------------------------------------------------------------------------
-   Copyright (c) 2008 Daniel C. Bünzli
+   Copyright (c) 2008 The uuidm programmers
 
    Permission to use, copy, modify, and/or distribute this software for any
    purpose with or without fee is hereby granted, provided that the above
